@@ -78,24 +78,26 @@ def send_sms():
     headers = request.headers or {}
     json_doc = request.get_json() or {}
     msisdn = json_doc["msisdn"]
-    if user.startswith('partenaire'):
-        sender_id = user.split('_')[1]
+    if (msisdn[-9:]).startswith("34"):
+        queue = CONFIG['orange']['account']
     else:
-        sender_id = json_doc.get('sender_id', 'bip')
-    try:
-        logging.warn(sender_id)
-        json_doc['sender_id'] = sender_id
-        queue = CONFIG[sender_id]['account']
-    except KeyError:
-        return bad_request(
-            message="Le sender_id n'exist pas",
-            code='{}-{}'.format(
-                SERVICE_CODE,
-                '4001'
-                ),
-            service_code=SERVICE_CODE
-            )
-        # queue = CONFIG['bip']['account']
+        if user.startswith('partenaire'):
+            sender_id = user.split('_')[1]
+        else:
+            sender_id = json_doc.get('sender_id', 'bip')
+        try:
+            logging.warn(sender_id)
+            json_doc['sender_id'] = sender_id
+            queue = CONFIG[sender_id]['account']
+        except KeyError:
+            return bad_request(
+                message="Le sender_id n'exist pas",
+                code='{}-{}'.format(
+                    SERVICE_CODE,
+                    '4001'
+                    ),
+                service_code=SERVICE_CODE
+                )
     document = {
         'auth': auth or (),
         'params': params,
